@@ -33,7 +33,6 @@ class version:
         :return: libjpeg version or None if not been loaded yet.
         :rtype: str, None
 
-
         :Example:
 
         >>> import jpeglib
@@ -58,5 +57,42 @@ class version:
     def versions():
         """Lists present DLLs of versions."""
         return CJpegLib.versions()
+    def __init__(self, version):
+        """Constructor, used in with statement.
+        
+        :param version: Version to set inside with block.
+        :type version: str
+        """
+        self.next = version
+    def __enter__(self):
+        """Sets new version in a block.
+
+        :Example:
+
+        >>> jpeglib.version.set('6b')
+        >>> # working with 6b
+        >>> # [...]
+        >>> with jpeglib.version('8d'):
+        >>>     # working with 8d
+        >>>     # [...]
+        >>>     pass
+        """
+        self.prev = self.get()
+        self.set(self.next)
+    def __exit__(self, *args, **kw):
+        """Recovers a previous version, when exiting `with` block.
+        
+        :Example:
+
+        >>> # working with 6b
+        >>> # [...]
+        >>> with jpeglib.version('8d'):
+        >>>     # working with 8d
+        >>>     # [...]
+        >>>     pass
+        >>> # working with 6b (again)
+        >>> # [...]
+        """
+        self.set(self.prev)
 
 __all__ = ['version']
\ No newline at end of file
